@@ -1,7 +1,7 @@
-def hello_world():
+def Hello_world():
     return "hello, world"
 
 
 if __name__ == '__main__':
-    str = hello_world()
+    str = Hello_world()
     print(str)
